@@ -132,6 +132,13 @@ class CastOp(UnaryUnaryOp):#{{{
 class DetectTypeOp(UnaryUnaryOp):#{{{
     __slots__ = []#}}}
 
+class DetectAndCastOp(DetectTypeOp):#{{{
+    __slots__ = ["allow_convert"]
+    
+    def __init__(self, source, name=None, rtype=None, dims=None, bookmarks=None, allow_convert=True):
+        self.allow_convert = allow_convert
+        UnaryUnaryOp.__init__(self, source,  name, rtype, dims, bookmarks)
+#}}}
 
 class DetectFixedShapesOp(UnaryUnaryOp):
     __slots__ = []
@@ -236,22 +243,26 @@ def broadcast(slices,mode="pos", partial=False):#{{{
         return ((),())
     slicedimpaths = [s.dims for s in slices]
     if(mode == "dim"):
-        bcdims, bcplan = dimpaths.planBroadcastMatchDim(slicedimpaths)
+        nbcdims, bcdims, bcplan = dimpaths.planBroadcastMatchDim(slicedimpaths)
     elif(mode == "pos"):
-        bcdims, bcplan = dimpaths.planBroadcastMatchPos(slicedimpaths)
+        nbcdims, bcdims, bcplan = dimpaths.planBroadcastMatchPos(slicedimpaths)
     else:
         raise RuntimeError, "Unknown broadcast mode: " + str(mode)
 
     references = defaultdict(list)
-    for bcdim in bcdims:
+    for bcdim,nbcdim in zip(bcdims,bcdims):
         for slice in slices:
             if bcdim in slice.dims:
-                references[bcdim].append(slice)
+                references[nbcdim].append(slice)
 
     nslices = []
     for plan,slice in zip(bcplan,slices):
         slice = apply_broadcast_plan(slice, plan, bcdims, references, partial)
         nslices.append(slice)
+
+    for slice in nslices:
+        #assert slice.dims == nslices[0].dims,'Dimension mismatch in broadcast: ' + str(slice.dims) + ' vs. ' + str(nslices[0].dims)
+        slice.dims = dimpaths.DimPath(*nbcdims) #HACK, we have to make the dims dependent on ids
     return (nslices, bcplan)
     #}}}
 
@@ -390,6 +401,7 @@ def filter(slice,constraint,seldimpath, ndim, mode="dim"):#{{{
     while True:
         #determine filter dim
         lastpos = slice.dims.matchDimPath(seldimpath)
+
         for filterpos in lastpos[::-1]:
              if(not used_dims[filterpos]):
                 break
@@ -417,7 +429,7 @@ def filter(slice,constraint,seldimpath, ndim, mode="dim"):#{{{
         #FIXME: change dependent dims of slice.type
 
         if(not ndim is None):
-            if(isinstance(tconstraint.type,rtypes.TypeSlice)):
+            if(isinstance(tconstraint.type,rtypes.TypeSlice) and seldimpath[-1].dependent): #if variable, extend variability
                 ndep = dimpaths.applyPlan(dep[::-1],cplan,newvalue=True, copyvalue=True, ensurevalue=True)
             else:
                 ndep = dimpaths.applyPlan(dep[::-1],cplan,newvalue=False)
@@ -444,7 +456,12 @@ def filter(slice,constraint,seldimpath, ndim, mode="dim"):#{{{
         #unpack dims
         if(packdepth):
             slice = UnpackArrayOp(slice,packdepth)
-            
+
+        #break out of loop if there was only one dim match (necessary to prevent 
+        #bug in which a dimpath starting with root gets matched multiple times)
+        if len(lastpos) <= 1:
+            break
+
     return slice#}}}
 
 class FlatAllOp(UnaryUnaryOp):#{{{
@@ -487,8 +504,8 @@ class UnpackTupleOp(UnaryUnaryOp):#{{{
         assert isinstance(stype, rtypes.TypeTuple), "Cannot unpack slice " + \
                                 str(slice.name) + " as it is not a tuple"
         
-        assert 0 <= idx < len(slice.type.subtypes), \
-            "Tuple index invalid, outside range of available attributes"
+        if not 0 <= idx < len(slice.type.subtypes):
+            raise RuntimeError, "Tuple index invalid, outside range of available attributes"
 
         ntype = slice.type.subtypes[idx]
         
