@@ -1,4 +1,5 @@
 import numpy
+import numpy as np
 import hashlib
 from itertools import izip
 import operator
@@ -16,7 +17,6 @@ import os.path
 import gc, sys
 import itertools
 import csv
-import cutils
 from logging import error,warning,info,debug
 
 #objs: objs to find names for
@@ -103,6 +103,47 @@ def seqgen(start=0):
         start += 1
         yield start
 
+def numpy_unique(ar, return_index=False, return_inverse=False):
+    """
+    Numpy unique with mergesort (works on strings too)
+    """
+    try:
+        ar = ar.flatten()
+    except AttributeError:
+        if not return_inverse and not return_index:
+            items = sorted(set(ar))
+            return np.asarray(items)
+        else:
+            ar = np.asanyarray(ar).flatten()
+
+    if ar.size == 0:
+        if return_inverse and return_index:
+            return ar, np.empty(0, np.bool), np.empty(0, np.bool)
+        elif return_inverse or return_index:
+            return ar, np.empty(0, np.bool)
+        else:
+            return ar
+
+    if return_inverse or return_index:
+        perm = ar.argsort()
+        aux = ar[perm]
+        flag = np.concatenate(([True], aux[1:] != aux[:-1]))
+        if return_inverse:
+            iflag = np.cumsum(flag) - 1
+            iperm = perm.argsort()
+            if return_index:
+                return aux[flag], perm[flag], iflag[iperm]
+            else:
+                return aux[flag], iflag[iperm]
+        else:
+            return aux[flag], perm[flag]
+
+    else:
+        ar.sort()
+        flag = np.concatenate(([True], ar[1:] != ar[:-1]))
+        return ar[flag]
+
+
 
 def unique(seq):
     """Given a list or tuple, returns a list or tuple in which each element
@@ -401,7 +442,7 @@ class memoized(object):
        return functools.partial(self.__call__, obj)
 
 def check_realseq(data):
-    return isinstance(data,collections.Sequence) and not isinstance(data, basestring)
+    return isinstance(data,(collections.Sequence, numpy.ndarray)) and not isinstance(data, basestring)
 
 def get_shape(data, lengths, pos=0):
     if check_realseq(data):
@@ -422,6 +463,9 @@ def fill(data, x, pos):
         x[:] = data
 
 def replace_darray(data, type=object, maxdim=1, mindim=0):
+    if isinstance(data,numpy.ndarray) and len(data.shape) >= mindim and len(data.shape) <= maxdim:
+        return data
+
     if maxdim == 1 and type == object:
         if not check_realseq(data):
             if mindim == 0:  return data
@@ -433,38 +477,31 @@ def replace_darray(data, type=object, maxdim=1, mindim=0):
                 x[pos] = e
             return x
        
-    try:
-        return cutils.darray(data,type,maxdim,mindim)
-    except ValueError:
-        if maxdim == 1:
-            if not check_realseq(data):
-                if mindim == 0:  return data
-                else: raise ValueError, "Object not deep enough"
-            else:
-                nlen = len(data)
-                x = numpy.zeros((nlen,),dtype=type)
-                x[:] = data
-                return x
-        #maxdim > 1        
-        lengths = [set() for i in range(maxdim)]
-        get_shape(data, lengths)
-        cusedim = 0
-        for lg in lengths:
-            if len(lg) == 1:
-                cusedim = cusedim + 1
-        if cusedim < mindim:
-            raise ValueError, "Object not deep enough"
-        shape = [lengths[i].pop() for i in range(cusedim)]
-        x = numpy.zeros(tuple(shape),dtype=type)
-        fill(data,x, len(x.shape))
-        return x
-        
+    if maxdim == 1:
+        if not check_realseq(data):
+            if mindim == 0:  return data
+            else: raise ValueError, "Object not deep enough"
+        else:
+            nlen = len(data)
+            x = numpy.zeros((nlen,),dtype=type)
+            x[:] = data
+            return x
+    #maxdim > 1        
+    lengths = [set() for i in range(maxdim)]
+    get_shape(data, lengths)
+    cusedim = 0
+    for lg in lengths:
+        if len(lg) == 1:
+            cusedim = cusedim + 1
+    if cusedim < mindim:
+        raise ValueError, "Object not deep enough"
+    shape = [lengths[i].pop() for i in range(cusedim)]
+    x = numpy.zeros(tuple(shape),dtype=type)
+    fill(data,x, len(x.shape))
+    return x
 
 nversion = numpy.__version__.split('.')    
 numpy16up = int(nversion[0]) >= 1 and int(nversion[1]) >= 6
 
-if numpy16up:
-    darray = replace_darray
-else:
-    darray = cutils.darray
+darray = replace_darray
     
