@@ -16,7 +16,7 @@ from .. import ops
 from ..utils.multi_visitor import VisitorFactory, DirectVisitorFactory, NF_ELSE
 
 _delay_import_(globals(),"..representor")
-_delay_import_(globals(),"..utils","util","cutils","nested_array","context")
+_delay_import_(globals(),"..utils","util","nested_array","context")
 _delay_import_(globals(),"..itypes","detector","type_attribute_freeze","convertors","dimensions")
 _delay_import_(globals(),"..repops_slice")
 _delay_import_(globals(),"..repops_dim")
@@ -881,9 +881,9 @@ class PyExec(VisitorFactory(prefixes=("visit","unpackCast"), flags=NF_ELSE),
         data = ensure_fixeddims(data,packdepth,type_in.toNumpy())
         dtype = type_out.toNumpy()
         if(packdepth > 1):
-           return util.darray([[numpy.unique(subrow,return_index=True)[1] for subrow in row.transpose()] for row in data],dtype,2,2)
+           return util.darray([[util.numpy_unique(subrow,return_index=True)[1] for subrow in row.transpose()] for row in data],dtype,2,2)
         else:
-           return util.darray([numpy.unique(row, return_index=True)[1] for row in data],dtype)
+           return util.darray([util.numpy_unique(row, return_index=True)[1] for row in data],dtype)
    
     def arrayarraySum(self, data, type_in, type_out, op, packdepth):
         data = ensure_fixeddims(data,packdepth,type_in.toNumpy())
